@@ -141,11 +141,11 @@ class Finder(ABC):
         return self.__webdriver
 
     @abstractmethod
-    def find_element(self, locator_tuple: tuple, timeout: str, explicit_timeout: int = None, condition: object = None) -> WebElement:
+    def find_element(self, locator_tuple: tuple, timeout: str = None, explicit_timeout: int = None, condition: object = None) -> WebElement:
         pass
 
     @abstractmethod
-    def find_elements(self, locator_tuple: tuple, timeout: str, explicit_timeout: int = None, condition: object = None) -> List[WebElement]:
+    def find_elements(self, locator_tuple: tuple, timeout: str = None, explicit_timeout: int = None, condition: object = None) -> List[WebElement]:
         pass
 
 
@@ -163,7 +163,7 @@ class FluentFinder(Finder):
         self.default_timeout = default_timeout
         super().__init__(webdriver, timeouts)
 
-    def find_element(self, locator_tuple: tuple, timeout: str, explicit_timeout: int = None) -> WebElement:
+    def find_element(self, locator_tuple: tuple, timeout: str = None, explicit_timeout: int = None) -> WebElement:
         try:
             t = self.timeouts[timeout.lower()] if timeout is not None else self.default_timeout
         except KeyError:
@@ -173,7 +173,7 @@ class FluentFinder(Finder):
         self.logger.debug(f'find_element: {locator_tuple}, timeout: {t} sec, condition: {con}')
         return WebDriverWait(self.webdriver, t).until(con)
 
-    def find_elements(self, locator_tuple: tuple, timeout: str, explicit_timeout: int = None) -> WebElement:
+    def find_elements(self, locator_tuple: tuple, timeout: str = None, explicit_timeout: int = None) -> WebElement:
         try:
             t = self.timeouts[timeout.lower()] if timeout is not None else self.default_timeout
         except KeyError:
